@@ -2,20 +2,14 @@
 import random
 
 
-def random_str(*args):
+def random_str():
     """
-    :param: *args 任意字符串组
     :return: str 随机字符串
     """
     choice = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789'
     a = ''
-    for arg in args:
-        if arg is None:
-            continue
-        a += arg if type(arg) == str else str(arg)
     for i in range(8):
         a += random.choice(choice)
-    print(a)
     return a
 
 
