@@ -148,7 +148,8 @@ class BaseRunner:
     def run_step(self, step_info):
         '''innermost run loop, where the step function run actually'''
         '''where the exceptions raise'''
-        time.sleep(1)
+        if self.option.slow:
+            time.sleep(1)
         if step_info.type == 'keyword' or step_info.type == 'assert':  # 运行type为keyword或者assert的步骤
             keyword = step_info.keyword
             a = [self._check_value(arg['value'], 'normal') for arg in keyword.args]
@@ -161,7 +162,7 @@ class BaseRunner:
                 exec_command = 'self.r = keyword.func(self.driver, *a{})'.format(s)
             else:
                 exec_command = 'self.r = keyword.func(*a{})'.format(s)
-            if step_info.description:
+            if hasattr(step_info, 'description') and step_info.description:
                 logger.info('执行步骤: 类型{}, 关键字{}, 描述:{}'.format(step_info.type, keyword.name, step_info.description))
             else:
                 logger.info('执行步骤: 类型{}, 关键字{}'.format(step_info.type, keyword.name))
@@ -174,10 +175,16 @@ class BaseRunner:
 
     # 关闭窗口删除cookies并打开新的窗口（适用于登录注册）
     def _delete_close_and_open(self):
-        self.driver.delete_all_cookies()
+        '''
+        self.driver.delete_all_cookies()  # 清除cookies
         self.driver.execute_script('window.open()')
         self.driver.close()
+        time.sleep(1)
+        input()
         self.driver.switch_to.window(self.driver.window_handles[-1])
+        '''
+        self.driver.quit()
+        self.driver = self.load_driver()
 
     # 关闭窗口并打开新的窗口
     def _close_and_open(self):
@@ -213,6 +220,7 @@ class BaseRunner:
         chrome_options = Options()
         chrome_options.add_argument('--no-sandbox')
         chrome_options.add_argument('--disable-dev-shm-usage')
+        chrome_options.add_experimental_option('excludeSwitches', ['enable-logging'])
         if self.option.driver_path:
             '''如果有指定driver_path参数，则忽略其他地址，出现异常直接raise'''
             driver = WebDriver(executable_path=self.option.driver_path, options=chrome_options)
